import { Providers } from "../providers";

import {
    Dialog,
    DialogContent,
    TextField,
    Tooltip,
    IconButton,
} from "@mui/material";
import {
    EyeOutline,
    PencilOutline,
    DeleteOutline,
    Delete,
} from "mdi-material-ui";
import React from "react";
import { useForm, usePage, Head, router } from "@inertiajs/react";
import Icon from "@mdi/react";
import { Button } from "@mui/material";
import { useState, useEffect, forwardRef } from "react";
import Box from "@mui/material/Box";
import MUIDataTable from "mui-datatables";
import MenuItem from "@mui/material/MenuItem";
import { CircularProgress } from "@mui/material";
import { List } from "@mui/material";
import Autocomplete from "@mui/material/Autocomplete";
// import Employees from "./Employees";
import Menu from "@mui/material/Menu";
import PropTypes from "prop-types";
import Tabs from "@mui/material/Tabs";
import Tab from "@mui/material/Tab";
import Typography from "@mui/material/Typography";
import NewPackage from "./NewPackage";
import AddImage from "./AddImage";
// import { DeleteOutline } from "@mui/icons-material";

function CustomTabPanel(props) {
    const { children, value, index, ...other } = props;

    return (
        <div
            role="tabpanel"
            hidden={value !== index}
            id={`simple-tabpanel-${index}`}
            aria-labelledby={`simple-tab-${index}`}
            {...other}
        >
            {value === index && (
                <Box sx={{ p: 3 }}>
                    <Typography>{children}</Typography>
                </Box>
            )}
        </div>
    );
}

CustomTabPanel.propTypes = {
    children: PropTypes.node,
    index: PropTypes.number.isRequired,
    value: PropTypes.number.isRequired,
};

function a11yProps(index) {
    return {
        id: `simple-tab-${index}`,
        "aria-controls": `simple-tabpanel-${index}`,
    };
}

export default function Packages() {
    const { flash, packages } = usePage().props;
    const handleAddEventSidebarToggle = () => setOpenDialog(!openDialog);
    const handleAddEventSidebarToggle2 = () => setOpenDialog2(!openDialog2);

    const [openProgress, setOpenProgress] = useState(false);
    const [currentItem, setCurrentItem] = useState([]);

    const CustomMenu = (props) => {
        const [anchorEl, setAnchorEl] = React.useState(null);
        const open = Boolean(anchorEl);
        const handleClick = (event) => {
            setAnchorEl(event.currentTarget);
        };
        const handleClose = () => {
            setAnchorEl(null);
        };

        return (
            <>
                <Button
                    variant="outlined"
                    onClick={() => {
                        props.setCurrentItem(
                            props.packages[props.tableMeta.rowIndex]
                        );
                        setOpenDialog(true);
                    }}
                >
                    EDIT
                </Button>
                <Button
                    variant="outlined"
                    className="uppercase"
                    onClick={() => {
                        props.setCurrentItem(
                            props.packages[props.tableMeta.rowIndex]
                        );
                        setOpenDialog2(true);
                    }}
                >
                    Maintainance
                </Button>
                <Menu
                    id="basic-menu"
                    anchorEl={anchorEl}
                    open={open}
                    onClose={handleClose}
                    MenuListProps={{
                        "aria-labelledby": "basic-button",
                    }}
                >
                    {props.packages[props.tableMeta.rowIndex].request_status ==
                    "Pending" ? (
                        <MenuItem
                            onClick={() => {
                                props.setOpenDialog(true);
                                props.setCurrentItem(
                                    props.packages[props.tableMeta.rowIndex]
                                );
                            }}
                        >
                            Detele Material Request
                        </MenuItem>
                    ) : (
                        <MenuItem
                            onClick={() => {
                                props.setOpenDialog(true);
                                props.setCurrentItem(
                                    props.packages[props.tableMeta.rowIndex]
                                );
                                console.log(
                                    "requesting ",
                                    props.packages[props.tableMeta.rowIndex]
                                );
                            }}
                        >
                            Request Materials
                        </MenuItem>
                    )}
                </Menu>
            </>
        );
    };
    const addEventSidebarWidth = 400;

    function getColor(status) {
        switch (status) {
            case "1":
                return "bg-green-500";
                break;
            case "0":
                return "bg-red-500";
                break;

            default:
                return "bg-gray-500 ";
                break;
        }
    }
    const [addImage, setAddImage] = useState(false);

    const columns = [
        {
            name: "name",
            label: "name",
            options: {
                filter: true,
                sort: true,
            },
        },
        {
            name: "image_cover",
            label: "Image",
            options: {
                filter: true,
                sort: true,
                customBodyRender: (value, tableMeta, updateValue, row) => (
                    <div
                        className={`text-center rounded-xl
                           `}
                    >
                        <img
                            alt={packages[tableMeta.rowIndex].name}
                            className="h-28 w-48 object-cover object-center rounded border border-gray-200"
                            src={`/${packages[tableMeta.rowIndex].cover_image}`}
                        />
                    </div>
                ),
            },
        },

        {
            name: "days",
            label: "days",
            options: {
                filter: true,
                sort: true,
                customBodyRender: (value, tableMeta, updateValue, row) => (
                    <div
                        className={` text-center rounded-xl
                           `}
                    >
                        {packages[tableMeta.rowIndex].no_of_days} days{" "}
                        {packages[tableMeta.rowIndex].no_of_night} nights
                    </div>
                ),
            },
        },
        {
            name: "starting_cost",
            label: "starting cost",
            options: {
                filter: true,
                sort: true,
                customBodyRender: (value, tableMeta, updateValue, row) => (
                    <div>$ {packages[tableMeta.rowIndex].starting_cost}</div>
                ),
            },
        },
        {
            name: "cost_per_person",
            label: "per person",
            options: {
                filter: true,
                sort: true,
                customBodyRender: (value, tableMeta, updateValue, row) => (
                    <div className={`text-center`}>
                        person: ${packages[tableMeta.rowIndex].cost_per_person}
                        <div>
                            child: ${packages[tableMeta.rowIndex].child_cost}
                        </div>
                        <div>
                            People: {packages[tableMeta.rowIndex].max_people}
                        </div>
                    </div>
                ),
            },
        },
        {
            name: "action",
            label: "Actions",
            options: {
                customBodyRender: (value, tableMeta, updateValue, row) => (
                    <Box
                        sx={{ display: "flex", alignItems: "start" }}
                        className="gap-2"
                    >
                        <Tooltip title="Edit">
                            <Box>
                                <div>
                                    <IconButton
                                        size="small"
                                        component="a"
                                        sx={{ textDecoration: "none", mr: 0.5 }}
                                        onClick={() => {
                                            setCurrentItem(
                                                packages[tableMeta.rowIndex]
                                            );
                                            setAddImage(true);
                                        }}
                                    >
                                        <PencilOutline className="text-blue-300" />
                                    </IconButton>
                                </div>
                            </Box>
                        </Tooltip>
                        <Tooltip title="View">
                            <Box>
                                <div>
                                    <IconButton
                                        size="small"
                                        component="a"
                                        sx={{ textDecoration: "none", mr: 0.5 }}
                                        onClick={() => {
                                            setCurrentItem(
                                                packages[tableMeta.rowIndex]
                                            );
                                            router.get(
                                                `/dashboard/edit-days/${
                                                    packages[tableMeta.rowIndex]
                                                        .id
                                                }`
                                            );
                                        }}
                                    >
                                        <EyeOutline className="text-blue-400" />
                                    </IconButton>
                                </div>
                            </Box>
                        </Tooltip>
                        <Tooltip title="Delete">
                            <Box>
                                <div>
                                    <IconButton
                                        size="small"
                                        component="a"
                                        sx={{ textDecoration: "none", mr: 0.5 }}
                                        onClick={() => {
                                            setCurrentItem(
                                                packages[tableMeta.rowIndex]
                                            );

                                            setOpenView(true);
                                        }}
                                    >
                                        <DeleteOutline className="text-red-400" />
                                    </IconButton>
                                </div>
                            </Box>
                        </Tooltip>
                    </Box>
                ),
            },
        },
    ];

    const [openDialog, setOpenDialog] = useState(false);
    const [openDialog2, setOpenDialog2] = useState(false);

    const { data, setData, post, processing, errors, wasSuccessful, reset } =
        useForm({
            user: "",
            password: "",
            role: "",
            password_confirmation: "",
        });

    const handleOnChange = (event) => {
        setData(
            event.target.name,
            event.target.type === "checkbox"
                ? event.target.checked
                : event.target.value
        );
    };

    const submit = (e) => {
        console.log("datas", data);
        setOpenProgress(true);
        e.preventDefault();
        post(route("register_user_admin"), {}, {});

        return;
    };

    useEffect(() => {
        if (flash && flash.success) {
            setOpenProgress(false);
            setOpenDialog(false);
            setOpenDialog2(false);
            setAddImage(false);
        }
    }, [flash]);

    const [role, setRole] = React.useState("");

    const handleChangeRole = (event) => {
        setRole(event.target.value);
    };

    const [value, setValue] = React.useState(0);

    const handleChange = (event, newValue) => {
        setValue(newValue);
    };

    return (
        <>
            {" "}
            <Head title="Packages" />
            <Providers>
                <Box sx={{ width: "100%" }}>
                    <Box sx={{ borderBottom: 1, borderColor: "divider" }}></Box>
                    <CustomTabPanel value={value} index={0}>
                        <Dialog open={openProgress}>
                            <DialogContent>
                                <CircularProgress />
                            </DialogContent>
                        </Dialog>
                        <NewPackage
                            currentMachine={currentItem}
                            drawerWidth={addEventSidebarWidth}
                            handleSelectEvent={() => {}}
                            addEventSidebarOpen={openDialog}
                            handleAddEventSidebarToggle={
                                handleAddEventSidebarToggle
                            }
                        />
                        <AddImage
                            currentItem={currentItem}
                            drawerWidth={addEventSidebarWidth}
                            handleSelectEvent={() => {}}
                            addEventSidebarOpen={addImage}
                            handleAddEventSidebarToggle={() =>
                                setAddImage(false)
                            }
                        />

                        <div className="pt-16">
                            <div className="flex justify-end mb-4">
                                <Button
                                    variant="contained"
                                    onClick={() => {
                                        setOpenDialog(true);
                                    }}
                                >
                                    New Package
                                </Button>
                            </div>
                            <MUIDataTable
                                title={"packages"}
                                data={packages}
                                columns={columns}
                                options={{ filter: true, sort: true }}
                            />
                        </div>
                    </CustomTabPanel>
                    <CustomTabPanel value={value} index={1}></CustomTabPanel>
                </Box>
            </Providers>
        </>
    );
}
